-- #######################################################
function setupSlashCommands()
	-- Setup slash commands, intended as a support mechanism for development testing; none of these will be needed by players
	-- In the final playable version, none of these comands will show up when /SC is typed; researchers can look in this file
	SlashCmdList["MarauderCOMMAND"] = MarauderSlashFunction;
	SLASH_MarauderCOMMAND1 = "/SC";
end
-- #######################################################



-- #######################################################
-- Slash commands
-- #######################################################
-- NOTE: hints for the slash commands are not printed OnLoad.. researcher will know about /SC
function MarauderSlashFunction(msg)
	local MarauderFrame = _G["Marauder"];


	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
	if (msg == nil or msg == "" or string.find(msg, "help") ~= nil) then
		trace("Maleante commands:");
		trace("  /SC resMode - enable participant researcher functions");
		trace("  /SC offMode - enable ScribeIzu for off-faction leader");
		trace("  /SC name#_______ - assign a name to the party");
		trace("  /SC clue#_______ - set the magic word");
		trace("  /SC status - send a message to all players to get MalVars.currQuest and MalVars.checkpoint status");
		trace("  /SC questproof - run through the animation of all quest windows");
		trace("  /SC sewerkills - force completion of rat/frog kills task");

	end
	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |


	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
	str1tosearch = string.find(msg,"resMode");
	if (str1tosearch ~= nil) then
		-- Register the player as researcher
		MalVars.isRes = 1; -- set this variable locally for checks on receiving messages
		SendAddonMessage("SRRv1", "Registering as researcher", "PARTY"); -- message not used, variable set based on sender
		--Also send a message to researcher logger here...

		-- Ensure button frame is visible
		MarauderRes:Show();
		--MarauderResVisible = true;
		MarauderAch:Show();
		AB1:Hide();
		AB2:Hide();
		AB3:Hide();
		AB4:Hide();
		AB5:Hide();
		AB6:Hide();
		AB7:Hide();
		AB8:Hide();
		AB9:Hide();
		AB13:Show();
		AB14:Show();
		AB15:Show();

		--Initialize researcher-only variables
		--SCVote1, SCVote2, SCVote3, SCVote4 = 0, 0, 0, 0; 			-- Party member tabard voting choices
		--SCZapped = 0; 												-- Only the first wrong emote starts the Zap cycle
		--SCZapPosition = 0; 											-- Checked during iteration of Zap cycle to move through party

	end; --of resMode slashcommand
	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |

	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
	str2tosearch = string.find(msg,"offMode");
	if (str2tosearch ~= nil) then
		--trace("Loading the ScribeIzu addon if it is installed and enabled...")
		--here do the launch command, like MarauderParticipant used to do.
		local already = IsAddOnLoaded("ScribeIzu")
		local bothaddons = IsAddOnLoaded("ScribeResearcher")
		if already == 1 then
			trace("|cffff8000Maleante|r: ScribeIzu is already loaded.")
		elseif bothaddons == 1 then
			trace("|cffff8000Maleante|r: WARNING: ScribeIzu cannot be run by the same avatar running ScribeResearcher.\nPlease disable one of these addons.");
		else
			local loaded, reason = LoadAddOn("ScribeIzu")
			--handle errors
			if not loaded then
				if reason == "DISABLED" then
					trace("|cffff8000Maleante|r: ScribeIzu is disabled. Please log out and enable that addon.")
				elseif reason == "MISSING" then
					trace("|cffff8000Maleante|r: ScribeIzu is missing. Please exit WoW and install that addon.")
				elseif reason == "CORRUPT" then
					trace("|cffff8000Maleante|r: ScribeIzu appears to be corrupt.")
				elseif reason == "INTERFACE_VERSION" then
					trace("|cffff8000Maleante|r: ScribeIzu appears to be out of date.")
				else
					trace("|cffff8000Maleante|r: ScribeIzu encountered an unknown error.")
				end
			elseif loaded == 1 then
				--must have succeeded
				trace("|cffff8000Maleante|r: ScribeIzu loaded")
				MarauderHat:Show();
			else
				trace("|cffff8000Maleante|r: ScribeIzu error 999")
			end
			if loaded ~= nil then
				--Send a message to off-fac researcher's log
				local output = "LD#" .. GetUnitName("Player") .. "#loaded ScribeIzu version " .. SCIzuVars.version .. ":status=" .. loaded .. "\r";
				sendToOffFacResearcherLogger(output, "ChatAndEvents", UnitName("Player"));
			end
		end;
	end
	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |



	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
	str2tosearch = string.find(msg,"status");
	if (str2tosearch ~= nil) then
		--trace("Sending a request to all players to get MalVars.currQuest and MalVars.checkpoint status...");
		SendAddonMessage("SRv1", "STATUS", "PARTY");
	end
	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |


	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
	str2tosearch = string.find(msg,"name");
	if (str2tosearch ~= nil) then
		--trace("Sending a message to all players to set the value of SCgroupname to the value typed in");
		local label, gpnm = strsplit("#", msg, 2);
		--print("split msg into " .. label .. " and " .. gpnm);
		SendAddonMessage("SRNAME", gpnm, "PARTY");
	end
	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |

		-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
	str2tosearch = string.find(msg,"clue");
	if (str2tosearch ~= nil) then
		--trace("Sending a message to all players to set the value of SCclue to the value typed in");
		local label, cluestring = strsplit("#", msg, 2);
		--print("split msg into " .. label .. " and " .. cluestring);
		local cluetosend = string.lower(cluestring);
		print("Set clue to: " .. cluetosend);
		SendAddonMessage("SRCLUE", cluetosend, "PARTY");
	end
	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |



		-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
	str3tosearch = string.find(msg,"questproof");
	if (str3tosearch ~= nil) then
		trace("Play animation sequence of all quest windows for text and layout proofing.");
		proofHandler();
	end
	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |


	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |
	str2tosearch = string.find(msg,"sewerkills");
	if (str2tosearch ~= nil) then
		--trace("Something went wrong with sewer kill task, don't want to wait for respawn... send message to force completion");
		SendAddonMessage("SRv1", "SEWERKILL", "PARTY");
	end
	-- | | | | | | | | | | | | | | | | | | | | | | | | | | | | | | |


end
-- #######################################################
